summaryrefslogtreecommitdiff
path: root/tests/modeltests/multiple_databases/models.py
diff options
context:
space:
mode:
Diffstat (limited to 'tests/modeltests/multiple_databases/models.py')
-rw-r--r--tests/modeltests/multiple_databases/models.py3
1 files changed, 2 insertions, 1 deletions
diff --git a/tests/modeltests/multiple_databases/models.py b/tests/modeltests/multiple_databases/models.py
index 9c974ef7bd..b9a1939d41 100644
--- a/tests/modeltests/multiple_databases/models.py
+++ b/tests/modeltests/multiple_databases/models.py
@@ -131,11 +131,12 @@ False
>>> artists[0]._meta.connection.settings == connections['django_test_db_a'].settings
True
# When not using transaction management, model save will commit only
# for the model's connection.
>>> from django.db import transaction
>>> transaction.enter_transaction_management()
+>>> transaction.managed(False)
>>> a = Artist(name="Joan Miro", alive=False)
>>> w = Widget(code="99rbln", weight=1)
>>> a.save()
@@ -131,11 +131,12 @@ False
>>> artists[0]._meta.connection.settings == connections['django_test_db_a'].settings
True
-# When not using transaction management, model save will commit only
+# When transactions are not managed, model save will commit only
# for the model's connection.
>>> from django.db import transaction